@@ -1,8 +1,12 @@
+from .imdecode import imdecode
+from .imencode import imencode
 from .imread import imread
 from .imshow import destroy_all_windows, imshow, waitkey
 from .imwrite import imwrite
 
 __all__ = [
+    "imdecode",
+    "imencode",
     "imread",
     "destroy_all_windows",
     "imshow",
